@@ -19,7 +19,7 @@ from jinja2.utils import contextfunction
 
 from pypuppetdb.QueryBuilder import *
 
-from puppetboard.forms import QueryForm
+from puppetboard.forms import ENABLED_QUERY_ENDPOINTS, QueryForm
 from puppetboard.utils import (get_or_abort, yield_or_stop,
                                get_db_version)
 from puppetboard.dailychart import get_daily_reports_chart
@@ -50,6 +50,7 @@ CATALOGS_COLUMNS = [
     {'attr': 'form', 'name': 'Compare'},
 ]
 
+
 app = get_app()
 graph_facts = app.config['GRAPH_FACTS']
 numeric_level = getattr(logging, app.config['LOGLEVEL'].upper(), None)
@@ -162,7 +163,8 @@ def index(env):
     nodes = get_or_abort(puppetdb.nodes,
                          query=query,
                          unreported=app.config['UNRESPONSIVE_HOURS'],
-                         with_status=True)
+                         with_status=True,
+                         with_event_numbers=app.config['WITH_EVENT_NUMBERS'])
 
     nodes_overview = []
     stats = {
@@ -243,7 +245,8 @@ def nodes(env):
     nodelist = puppetdb.nodes(
         query=query,
         unreported=app.config['UNRESPONSIVE_HOURS'],
-        with_status=True)
+        with_status=True,
+        with_event_numbers=app.config['WITH_EVENT_NUMBERS'])
     nodes = []
     for node in yield_or_stop(nodelist):
         if status_arg:
@@ -691,7 +694,7 @@ def fact_ajax(env, node, fact, value):
     try:
         value = int(value)
     except ValueError:
-        if value is not None:
+        if value is not None and query is not None:
             query.add(EqualsOperator('value', unquote_plus(value)))
     except TypeError:
         pass
@@ -758,36 +761,42 @@ def query(env):
         select field in the environment block
     :type env: :obj:`string`
     """
-    if app.config['ENABLE_QUERY']:
-        envs = environments()
-        check_env(env, envs)
+    if not app.config['ENABLE_QUERY']:
+        log.warn('Access to query interface disabled by administrator.')
+        abort(403)
 
-        form = QueryForm(meta={
-            'csrf_secret': app.config['SECRET_KEY'],
-            'csrf_context': session})
-        if form.validate_on_submit():
-            if form.endpoints.data == 'pql':
-                query = form.query.data
-            elif form.query.data[0] == '[':
-                query = form.query.data
-            else:
-                query = '[{0}]'.format(form.query.data)
-            result = get_or_abort(
-                puppetdb._query,
-                form.endpoints.data,
-                query=query)
-            return render_template('query.html',
-                                   form=form,
-                                   result=result,
-                                   envs=envs,
-                                   current_env=env)
+    envs = environments()
+    check_env(env, envs)
+
+    form = QueryForm(meta={
+        'csrf_secret': app.config['SECRET_KEY'],
+        'csrf_context': session})
+    if form.validate_on_submit():
+        if form.endpoints.data not in ENABLED_QUERY_ENDPOINTS:
+            log.warn('Access to query endpoint %s disabled by administrator.',
+                     form.endpoints.data)
+            abort(403)
+
+        if form.endpoints.data == 'pql':
+            query = form.query.data
+        elif form.query.data[0] == '[':
+            query = form.query.data
+        else:
+            query = '[{0}]'.format(form.query.data)
+
+        result = get_or_abort(
+            puppetdb._query,
+            form.endpoints.data,
+            query=query)
         return render_template('query.html',
                                form=form,
+                               result=result,
                                envs=envs,
                                current_env=env)
-    else:
-        log.warn('Access to query interface disabled by administrator..')
-        abort(403)
+    return render_template('query.html',
+                           form=form,
+                           envs=envs,
+                           current_env=env)
 
 
 @app.route('/metrics', defaults={'env': app.config['DEFAULT_ENVIRONMENT']})
@@ -1104,3 +1113,8 @@ def offline_static(filename):
 
     return Response(response=render_template('static/%s' % filename),
                     status=200, mimetype=mimetype)
+
+
+@app.route('/status')
+def health_status():
+    return 'OK'
