@@ -2,7 +2,7 @@ import os
 
 PUPPETDB_HOST = os.getenv('PUPPETDB_HOST', 'puppetdb')
 PUPPETDB_PORT = int(os.getenv('PUPPETDB_PORT', '8080'))
-# Since this is an env it will alwas be a string, we need
+# Since this is an env it will always be a string, we need
 # to conver that string to a bool
 SSL_VERIFY = os.getenv('PUPPETDB_SSL_VERIFY', 'True')
 if SSL_VERIFY.upper() == 'TRUE':
@@ -14,6 +14,7 @@ else:
 
 PUPPETDB_KEY = os.getenv('PUPPETDB_KEY', None)
 PUPPETDB_CERT = os.getenv('PUPPETDB_CERT', None)
+PUPPETDB_PROTO = os.getenv('PUPPETDB_PROTO', None)
 PUPPETDB_TIMEOUT = int(os.getenv('PUPPETDB_TIMEOUT', '20'))
 DEFAULT_ENVIRONMENT = os.getenv('DEFAULT_ENVIRONMENT', 'production')
 SECRET_KEY = os.getenv('SECRET_KEY', os.urandom(24))
@@ -22,6 +23,8 @@ DEV_LISTEN_PORT = int(os.getenv('DEV_LISTEN_PORT', '5000'))
 DEV_COFFEE_LOCATION = os.getenv('DEV_COFFEE_LOCATION', 'coffee')
 UNRESPONSIVE_HOURS = int(os.getenv('UNRESPONSIVE_HOURS', '2'))
 ENABLE_QUERY = os.getenv('ENABLE_QUERY', 'True')
+# Uncomment to restrict the enabled PuppetDB endpoints in the query page.
+# ENABLED_QUERY_ENDPOINTS = ['facts', 'nodes']
 
 LOCALISE_TIMESTAMP = bool(os.getenv('LOCALISE_TIMESTAMP',
                                     'True').upper() == 'TRUE')
@@ -43,6 +46,7 @@ DISPLAYED_METRICS = [x.strip() for x in os.getenv('DISPLAYED_METRICS',
 OFFLINE_MODE = bool(os.getenv('OFFLINE_MODE', 'False').upper() == 'TRUE')
 ENABLE_CATALOG = bool(os.getenv('ENABLE_CATALOG', 'False').upper() == 'TRUE')
 OVERVIEW_FILTER = os.getenv('OVERVIEW_FILTER', None)
+PAGE_TITLE = os.getenv('PAGE_TITLE', 'Puppetboard')
 
 GRAPH_FACTS_DEFAULT = ','.join(['architecture', 'clientversion', 'domain',
                                 'lsbcodename', 'lsbdistcodename', 'lsbdistid',
